config library

Classes

ConfigModule
A ControlModule that integrates control_config with the ControlFactory.
ControlPrefs
A robust wrapper around SharedPreferences for simplified and type-safe data persistence.
PrefModel<T>
A concrete implementation of PrefModelBase for common data types.
PrefModelAsync<T>
A base class for reactive preference models that handle asynchronous value retrieval.
PrefModelBase<T, U>
A base class for creating reactive models that wrap preference values.

Mixins

PrefsProvider
A mixin that provides easy access to the ControlPrefs instance.

Typedefs

ValueDelegateGetter<T> = T Function()
ValueDelegateSetter<U> = void Function(U value)