entries property

Map get entries
inherited

A map of singleton instances to be registered in the ControlFactory.

The key is typically a Type, and the value is the object instance. By default, it registers the module instance under its key.

Implementation

Map get entries => {key: module};